@@ -503,7 +503,7 @@ class XInvoice(XEntity):
     def __init__(self,
                  ctype=InvoiceType.ACCREC,
                  status=InvoiceStatus.DRAFT,
-                 line_amount_types=InvoiceLineAmountType.Inclusive):
+                 line_amount_types=InvoiceLineAmountType.Exclusive):
         """
         Constructs a new :class:`XInvoice` model instance.
         """
@@ -888,6 +888,11 @@ class XBrandingTheme(XEntity):
         if not response["Response"].has_key("BrandingThemes"):
             return retval
 
+        # If only one instance is returned, xml2json returns
+        # dictionary. Put the single item back into a list.
+        if isinstance(response["Response"]["BrandingThemes"]["BrandingTheme"], dict):
+            response["Response"]["BrandingThemes"]["BrandingTheme"] = [response["Response"]["BrandingThemes"]["BrandingTheme"]]
+
         # Iterate over the values:
         for item in response["Response"]["BrandingThemes"]["BrandingTheme"]:
             retval.append(XBrandingTheme(item))
@@ -950,6 +955,11 @@ class XTaxRate(XEntity):
         if not response["Response"].has_key("TaxRates"):
             return retval
 
+        # If only one instance is returned, xml2json returns
+        # dictionary. Put the single item back into a list.
+        if isinstance(response["Response"]["TaxRates"]["TaxRate"], dict):
+            response["Response"]["TaxRates"]["TaxRate"] = [response["Response"]["TaxRates"]["TaxRate"]]
+
         # Iterate over the values:
         for item in response["Response"]["TaxRates"]["TaxRate"]:
             retval.append(XTaxRate(item))
